@@ -1,4 +1,3 @@
 from .parse import parse_query
-from .feature import generate_feature
-from .format import format_query
+from .format import format_query, get_allowed_dialects
 from .clean import clean_spaces, clean_query
\ No newline at end of file
